#
# spec file for package python-heatclient
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-heatclient
Version:        4.0.0
Release:        1.2
Summary:        Python API and CLI for OpenStack Heat
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/python-heatclient
Source0:        https://files.pythonhosted.org/packages/source/p/python-heatclient/python-heatclient-4.0.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-PyYAML >= 3.13
BuildRequires:  python3-cliff >= 2.8.0
BuildRequires:  python3-devel
BuildRequires:  python3-fixtures
BuildRequires:  python3-osc-lib >= 1.14.0
BuildRequires:  python3-oslo.serialization >= 2.18.0
BuildRequires:  python3-pbr >= 2.0.0
BuildRequires:  python3-requests-mock
BuildRequires:  python3-stestr
BuildRequires:  python3-swiftclient >= 3.2.0
BuildRequires:  python3-testscenarios
BuildRequires:  python3-testtools
Requires:       python3-Babel
Requires:       python3-PrettyTable >= 0.7.2
Requires:       python3-PyYAML >= 3.13
Requires:       python3-cliff >= 2.8.0
Requires:       python3-iso8601 >= 0.1.11
Requires:       python3-keystoneauth1 >= 3.8.0
Requires:       python3-osc-lib >= 1.14.0
Requires:       python3-oslo.i18n >= 3.15.3
Requires:       python3-oslo.serialization >= 2.18.0
Requires:       python3-oslo.utils >= 3.33.0
Requires:       python3-requests >= 2.14.2
Requires:       python3-swiftclient >= 3.2.0
BuildArch:      noarch

%description
This is a client for the OpenStack Heat API. There's a Python API (the
heatclient module), and a command-line script (heat). Each implements 100% of
the OpenStack Heat API.

%package -n python3-heatclient
Summary:        Python API and CLI for OpenStack Heat
Requires:       python3-Babel
Requires:       python3-PrettyTable >= 0.7.2
Requires:       python3-PyYAML >= 3.13
Requires:       python3-cliff >= 2.8.0
Requires:       python3-iso8601 >= 0.1.11
Requires:       python3-keystoneauth1 >= 3.8.0
Requires:       python3-osc-lib >= 1.14.0
Requires:       python3-oslo.i18n >= 3.15.3
Requires:       python3-oslo.serialization >= 2.18.0
Requires:       python3-oslo.utils >= 3.33.0
Requires:       python3-requests >= 2.14.2
Requires:       python3-swiftclient >= 3.2.0
%if 0%{?suse_version}
Obsoletes:      python2-heatclient < 2.0.0
%endif

%description -n python3-heatclient
This is a client for the OpenStack Heat API. There's a Python API (the
heatclient module), and a command-line script (heat). Each implements 100% of
the OpenStack Heat API.

%package -n python-heatclient-doc
Summary:        Documentation for OpenStack Heat API Client
Group:          Documentation/HTML
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme

%description -n python-heatclient-doc
This is a client for the OpenStack Heat API. There's a Python API (the
heatclient module), and a command-line script (heat). Each implements 100% of
the OpenStack Heat API.
This package contains auto-generated documentation.

%prep
%autosetup -p1 -n python-heatclient-4.0.0
%py_req_cleanup

%build
%{py3_build}

PBR_VERSION=4.0.0 %sphinx_build -b html doc/source doc/build/html
PBR_VERSION=4.0.0 %sphinx_build -b man doc/source doc/build/man
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py3_install}
# man page
install -p -D -m 644 doc/build/man/heat.1 %{buildroot}%{_mandir}/man1/heat.1
# bash completion
install -p -D -m 644 tools/heat.bash_completion %{buildroot}%{_sysconfdir}/bash_completion.d/heat.bash_completion

%check
%{openstack_stestr_run}

%files -n python3-heatclient
%license LICENSE
%{python3_sitelib}/heatclient
%{python3_sitelib}/*.egg-info
%{_bindir}/heat
%{_mandir}/man1/heat.1*
%{_sysconfdir}/bash_completion.d/heat.bash_completion

%files -n python-heatclient-doc
%license LICENSE
%doc doc/build/html README.rst

%changelog
* Tue Sep  3 2024 cloud-devel@suse.de
- update to version 4.0.0
  - Remove Python 3.8 support
  - reno: Update master for unmaintained/xena
  - reno: Update master for unmaintained/victoria
  - Fix storyboard links
  - reno: Update master for unmaintained/zed
  - Remove old excludes
  - Update master for stable/2024.1
  - reno: Update master for unmaintained/wallaby
* Sun Mar 24 2024 cloud-devel@suse.de
- update to version 3.5.0
  - Bump hacking
  - Remove leftover of Python <= 2.6 support
  - Remove some notes no longer valid
  - Make tests pass after 2038
  - Remove translation sections from setup.cfg
  - remove unicode prefix from code (2)
  - remove unicode prefix from code (1)
  - Fix osc sd create command
  - Fix release note generation
  - reno: Update master for unmaintained/yoga
  - Update master for stable/2023.2
  - Add Python 3.11 to supported runtimes
* Sun Jan 14 2024 cloud-devel@suse.de
- update to version 3.3.0
  - Add Python 3.10 to supported runtime.
  - Switch to 2023.1 Python3 unit tests and generic template name
  - Update master for stable/2023.1
* Tue Mar  7 2023 cloud-devel@suse.de
- update to version 3.2.0
  - Adapt to tox 4
  - Update master for stable/zed
  - Imported Translations from Zanata
* Thu Dec  1 2022 cloud-devel@suse.de
- update to version 3.1.0
  - Encode urls in unit tests
  - Accept sha256 hash for swift tempurl
  - Replace deprecated UPPER_CONSTRAINTS_FILE variable
  - Update master for stable/yoga
  - Drop lower-constraints.txt and its testing
  - The Python 3.6 and Python 3.7 Support has been dropped since zed
  - Add Python3 zed unit tests
  - Remove six
  - Bump tox minversion to 3.18.0
* Tue May 24 2022 cloud-devel@suse.de
- update to version 2.5.1
  - Update master for stable/xena
  - Update python testing classifier
  - Replace deprecated import of ABCs from collections
  - Add Python3 yoga unit tests
  - Fix test and lower constraints
  - setup.cfg: Replace dashes by underscores
* Tue Oct 26 2021 cloud-devel@suse.de
- update to version 2.4.0
  - Update master for stable/wallaby
  - [ussuri][goal] Update contributor documentation
  - Replace oslo_utils.fnmatch with fnmatch
  - Add Python3 xena unit tests
  - fix lower constraint job
* Sun May  2 2021 cloud-devel@suse.de
- update to version 2.3.0
  - Bump default tox env from py37 to py38
  - Update master for stable/victoria
  - Python 3.9: base64.encodestring is removed
  - Stop to use the __future__ module.
  - [goal] Migrate testing to ubuntu focal
  - Add Python3 wallaby unit tests
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 2.2.1
  - Add py38 package metadata
  - Fix hacking min version to 3.0.1
  - Native Zuul v3 version of the functional legacy job
  - Update master for stable/ussuri
  - Use unittest.mock instead of third party mock
  - Add Python3 victoria unit tests
  - Switch to newer openstackdocstheme and reno versions
* Tue May 12 2020 cloud-devel@suse.de
- update to version 2.1.0
  - Cap sphinx for py2 to match global requirements
  - [ussuri][goal] Drop python 2.7 support and testing
  - Update hacking for Python3
  - Cleanup of .keys() from dict_object.keys() *in* operator
  - Replace git.openstack.org URLs with opendev.org URLs
  - Allow to set poll interval to OSC stack create
  - Add files-container option for stack create and update
  - tests: Convert 'test_resources' to mock
  - Ignore not found when delete in test
  - Remove mox usage from test_shell
  - Remove dependency on mox3
  - Update master for stable/train
  - Change openstack-dev to openstack-discuss
  - tests: Pre-mox removal cleanup
* Mon Mar 23 2020 Dirk Mueller <dmueller@suse.com>
- add obsoletes
* Wed Mar 11 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only build
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 1.18.0
  - Update stack_id clearify for heat client functions
  - Dropping the py35 testing
  - Update master for stable/stein
  - Fix missing print format
  - Add Python 3 Train unit tests
  - Replace openstack.org git:// URLs with https://
  - add python 3.7 unit test job
  - OpenDev Migration Patch
  - Set Content-Type header explictly for SessionClient
  - Fix unit tests
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 1.17.0
  - Don't change pyyaml behavior
  - Switch to stestr
  - Update min tox version to 2.0
  - Set X-Region-Name in header when using SessionClient
  - fix bug link in readme
  - Migrate the link of bug report button to storyboard
  - Load files from adopt file when adopt stack
  - Update the bugs link to storyboard
  - Trivial: Update pypi url to new url
  - Update reno for stable/rocky
  - Replace deprecated "decodestring()" by "decodebytes()"
  - Don't quote {posargs} in tox.ini
  - switch documentation job to new PTI
  - add python 3.6 unit test job
  - import zuul job settings from project-config
  - Use templates for cover and lower-constraints
* Sat Sep  1 2018 cloud-devel@suse.de
- update to version 1.16.1
  - Updated from global requirements
  - fix tox python3 overrides
  - Remove PyPI downloads
  - Update reno for stable/queens
  - Zuul: Remove project name
  - Enable some off-by-default checks
  - Fix log_http_request function in http module
  - Mark stacks returned by get loaded
  - Using fixtures instead of deprecated mockpatch module
  - Add heat CLI test for stack-show
  - Update the documentation link for doc migration
  - Improve titles of generated API documentation
  - Mark python-heatclient as stable
  - Fix osc cli docs
  - Follow the new PTI for document build
  - Change testenv from py34 to py35
  - Document osc CLI
  - Use assertRegex instead of assertRegexpMatches
  - [policy in code] Change policy description
  - add lower-constraints job
  - Handle token_endpoint auth type in osc plugin
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Feb 12 2018 cloud-devel@suse.de
- update to version 1.14.0 (bsc#1078607)
  - Add reno for release notes management
  - Updated from global requirements
  - Fix release note formatting
  - Avoid tox_install.sh for constraints support
  - Migrate functional job to Zuul v3
* Fri Jan 19 2018 cloud-devel@suse.de
- update to version 1.13.0
  - Add plug-in summary for osc doc
  - Add --no-rollback option for stack cancel
  - Add `--converge` argument for osc stack update
  - No longer use oslotest.mockpatch
  - Use generic user for both zuul v2 and v3
  - Modify error message encountered during stack update
  - Decode content before checking
  - Support --show-nested in openstack stack update --dry-run
  - Don't override sections in deep_update
  - Imported Translations from Zanata
  - Don't preformat stack output show list/map values
  - Remove vestigate HUDSON_PUBLISH_DOCS reference
  - Allow cancelling create_in_progress stacks with --no-rollback
  - Updated from global requirements
  - Use Sphinx 1.5 warning-is-error
- Convert to singlespec
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 1.11.0
  - Handle log message interpolation by the logger
  - Explicitly set 'builders' option
  - Don't encode path separators
  - Show 'project' info if heat server returns
  - Trivial:remove unused code
  - Support openstack stack export
  - Use endpoint_type with session client
  - Replace six.iteritems() with .items()
  - Don't always resolve outputs when showing a stack
  - Fixing read before prompt bug
  - Use upper-constraints for all jobs
  - Fix error message when deployment not found
  - Switch from oslosphinx to openstackdocstheme
  - Add functinoal tests for 'openstack stack snapshot delete'
  - Add optional arguments '-y' in CLI：snapshot-delete
  - Replace mox3 with mock
  - Build event stack_name from links
  - Remove log translations
  - Add '--yes' for openstack stack snapshot delete
  - Update test requirement
  - Remove support for py34
  - Pass event filters to the server side
  - Updated from global requirements
* Wed Jun  7 2017 cloud-devel@suse.de
- update to version 1.8.1
  - Build event stack_name from links
  - Update .gitreview for stable/ocata
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 1.8.0:
  - Add url in setup.cfg
  - Make method import_versioned_module work
  - Add convenience function for events over websocket
  - Graduate to oslo.i18n and cleanup incubator usage
  - Enable coverage report in console output
  - Distinguish between stack and resource events when polling
  - Add heat CLI test for creating stack from URL
  - Fix help string for osc resource show <resource>
  - Fix "heat output-show -F json" output format
  - Remove LOG Warning from __eq__
  - delete python bytecode including pyo before every test run
  - User server side env merging with osc plugin
  - Remove oslo-incubator modules
  - Show team and repo badges on README
  - Update headers for the Openstack Orchestration commands
  - Remove unused scripts in tools
  - Support -y for --yes.
  - Use default service_type with session
  - handle empty sections in environment files
  - Make sure the --heat-url option is respected, part 2
  - Update docs for mark-unhealthy command
  - Don't resolve outputs when polling events
  - Move required modules from oslo-incubator
  - Fix doc on keystoneauth session api usage
  - Use region_name and interface with session
  - Add aliases to orchestration template version list
  - Change property option into append action
  - Don't use endpoint_override with session
  - Use endpoint as endpoint_override
  - Return condition functions based on the filter param
  - Use event_time as default event sort key in OSC
  - Add heat CLI test for deleting stack
  - Improved the help message of the stack-list tags
  - Updated from global requirements
  - Fix event list help
* Mon Sep 26 2016 tbechtold@suse.com
  update to version 1.5.0
  * Replace functions 'Dict.get' and 'del' with 'Dict.pop'
  * Trivial:Standardize the output format of 'help' in shell.py
  * Show resource name path in event log formatter
  * Clean imports in code
  * Add parameter_merge_startegies section
  * Modify use of assertTrue(A in B)
  * Update .gitreview for stable/newton
  * Import mox in __init__.py
* Tue Aug 30 2016 tbechtold@suse.com
- update to 1.4.0:
  * Updated from global requirements
  * Add a nested_depth argument to poll_for_events
  * Update the home-page in setup.cfg
  * Standardize import format
  * Remove unused function
  * Change usage of _auth_url private attribute
  * Remove discover from test-requirements
  * Add support for stack file list
  * Trivial: Remove out-of-date and useless example
  * Add Python 3.5 classifier and venv
  * Fix doc build if git is absent
  * Fix deprecation message for stack-preview
  * Remove unused LOG
  * Remove white space between print and ()
  * base.Resource not define __ne__() built-in function
  * Fix typo
  * Pass correct arguments in osc plugin
  * Use osc_lib instead of cliff
  * Use osc-lib instead of openstackclient
  * Imported Translations from Zanata
  * Enhance error message
  * Replace dict.iteritems with six.iteritems to make PY3 compatible
  * Show 'deletion_time' of stacks
  * Implement client side of event list --nested-depth
  * Refactor test_shell
  * Serialize files when using SessionClient
  * Show 'parameter_defaults' for environment-show
  * A resource list formatter for graphviz dot diagrams
  * Implement "openstack stack failures list"
  * Clean up osc fakes and mocks
  * osc resource-type-show description option
  * osc resource-type-list description option
  * Remove redundant auth discovery
  * switch to keystoneauth
  * Allow redirects to use location from response
  * Fix obscure error message when no template given to OSC
  * Replace tempest-lib with tempest.lib
  * Moved required parameter for visibility
  * use thread safe fnmatch
  * OpenStack client plugin for environment show
  * Add client library support for retrieving a stack's environment
  * Support "--pre-delete" argument for hook-clear
  * Fixed fragile assertion in test_template_utils
  * Fix logging issue in heatclient tests
  * Add basic read-only function test for template validate
  * Support OS_KEY/OS_CERT environment variables
  * Replace assertRegexpMatches with assertRegex
  * Moved -t parameter for visibility
  * Move OpenStack client to test-requirements
  * OSC plugin for orchestration template validate
  * Use stack.get for resolving outputs for old API
- update _service and switch to upstream spec template
* Wed Jul 13 2016 tbechtold@suse.com
- update to 1.1.0:
  * Updated from global requirements
  * Fix regression handling relative paths in environment
  * Update .gitreview for stable/mitaka
  * Use poll_for_events for "openstack stack delete"
  * Add OSC plugin for openstack orchestation service list
  * Add OSC plugin for openstack orchestation build info
  * Strip any whitespace before checking for json
  * Add OSC plugin for stack resource mark unhealthy
  * Implement stack event list --follow
  * Replace assertEqual(None, *) with assertIsNone
  * Prompt user before deleting stack if tty
  * Add more readonly openstack client funcitonal tests
  * Use poll_for_events for "openstack stack <action>"
  * Use poll_for_events for "openstack stack adopt"
  * Use poll_for_events for "openstack stack update"
  * Use poll_for_events for "openstack stack create"
  * poll_for_events fall back to stack get
  * Fix collision with update and update cancel
  * Update OSC metavars
  * OpenstackClient plugin for software deployment output show
  * Move poll_for_events to event_utils
  * Adds --filter to search for resources
  * Stack resource search
  * OpenstackClient plugin for software deployment metadata show
  * Add stack hook poll and clear to openstack client
  * OpenstackClient plugin for deployment create
  * Remove the only-value flag of output-show
  * Changes to support server-side environment resolution
  * OSC plugin for stack snapshot delete
  * OSC plugin for stack snapshot create
  * Use yaml.safe_load() instead of yaml.load()
  * Use oslo.utils.reflection to extract class name
  * Add OpenstackClient plugin for software deployment show
  * Add openstack client stack snapshot restore
  * Add openstack client stack resource signal
  * OSC plugin for stack resource show and list
  * OpenstackClient plugin for event list
  * OpenstackClient plugin for event show
  * OpenstackClient plugin for stack delete
  * Fix resource_type osc entrypoint
  * OSC plugin for software config show
  * Add openstack cli stack actions
  * Add openstack client resource type list and show
  * OSC plugin for stack snapshot show
  * Add openstack client software config create
  * OpenstackClient plugin for template show
  * OpenStackClient plugin for stack output list
  * OpenstackClient plugin for stack output show
  * Add openstack client software config list
  * Add openstack client stack resource metadata show
  * Adds ignore_errors for template-validate command
  * Add heat client support for Resource set health
  * Sort osc command entry points
  * OpenstackClient plugin for template function list
  * OpenstackClient plugin for template version list
  * Add OpenstackClient plugin for software deployment list
  * Add openstack client software config delete
  * OpenstackClient plugin for stack abandon
  * OpenstackClient plugin for stack adopt
  * OpenstackClient plugin for software deployment delete
  * Add openstack client stack basic funtion tests
  * Remove incorrectly used "# flake8: noqa"
  * Update translation setup
  * Edit backslashes for lines continuations
  * Raise CommandError when Any of stack/deployment/config delete failed
  * Ignore restricted_actions key
  * Add formatters for 'tags' in method _do_stack_show
  * Enable osc extension in setup.cfg
  * Disable osc extension for 0.9.0 release
  * Remove argparse from requirements
  * Add openstack client stack snapshot list
  * Add --dry-run option to openstack stack create
  * Include keystone message when authentication failed
  * Add show_nested support to update --dry-run
  * Update template_utils to support object env's
  * Improve "openstack stack create --wait" help message
  * OpenstackClient plugin for stack update
  * OpenstackClient plugin for stack create
  * Validate for empty file for stack-adopt
  * Misspelling in message
  * Add resolve_outputs parameter to stack get method
  * Allow event specification in the environment
  * Add debug testenv in tox
  * Replace deprecated library function os.popen() with subprocess
  * Update --template-object to support nested stacks
  * Added -P support to template-validate
  * Fix error message on authentication failure
  * Change LOG.warn to LOG.warning
  * use keystoneclient exceptions instead of oslo-incubator code
  * Resolve outputs from stack object
  * Use stack lookup for getting stack name/id
  * Replace assertEqual(None, *) with assertIsNone in tests
  * Removes MANIFEST.in as it is not needed explicitely by PBR
  * Fix Resource.__eq__ mismatch semantics of object equal
  * remove py26 specific code from heatclient
  * Deprecated tox -downloadcache option removed
  * remove py26 support tag in setup.cfg
  * Add JsonFormat display option
  * Remove py26 support
  * Delete python bytecode before every test run
  * Enable pep8 E123 test
  * Enable pep8 E126 test
  * Enable pep8 E128 test
  * Enable pep8 E265 test
  * Enable pep8 E241 test
  * Enable pep8 E713 test
  * Use six.iteritems() instead of iter(XXX.items())
  * Fix error when listing stacks
  * OpenStack typo
  * Enable pep8 H202 test
  * Enable pep8 H238 test
  * Enable pep8 H405 tests
  * Add output API calls implementations
  * Refine event_log_formatter output
  * Last sync from oslo-incubator
  * Delete the corresponding config when deleting a deployment
  * OpenStackClient plugin for stack list
  * Fix environment files parsing bug for stack-adopt
  * Support to list software configs
  * Ignore .eggs
  * OpenStackClient plugin for stack show
  * Fix error in stack-list metadata
  * improve readme content
  * Add option for detailed template error
  * Add standard code coverage configuration file
  * Add PATCH support for stack-update --dry-run
  * Fix the bug when showing event in log format
- Adjust Requires
- Add 0001-Fix-doc-build-if-git-is-absent.patch
* Sat Sep 19 2015 tbechtold@suse.com
- update to 0.8.0:
  * stack-update -x tolerate no template
  * Ability to specify show_nested for template validation
  * Fix deployment create error when using  existing config
  * Fix stack sorting support
  * Enable filters for heat resource-type-list
  * Modify test templates and the path to subunit2html
  * Add CLI option for update dry-run
  * Add py34 env to default tox run
* Mon Sep 14 2015 tbechtold@suse.com
- update to 0.7.0:
  * Fix a nit in resource-list help
  * Replace deprecated function
  * Updated from global requirements
  * Improve the format hint of -Pf option
  * Support tags parameter for stack-preview
  * Do not show snapshot data when doing snapshot-list
  * Updated from global requirements
  * Poll functionality for stack create action
  * Updated from global requirements
  * Use Heat resource to validate resource_type_show
  * Update python3 classifiers
  * Updated from global requirements
  * Updated from global requirements
  * add with_detail parameter in heat resource-list request
  * Fix docstrings and add missing
  * Add missing `deployment-list` to cli
  * Updated from global requirements
  * Support 'with_attr' parameter for resource-show
  * Updated from global requirements
  * New mock release(1.1.0) broke unit tests
  * Fix error when creating deployment from cli
  * Add support for template-function-list command
  * Fix TypeError when call keystoneclient session.request()
  * Add support for template-version-list command
  * Add tests for SessionClient
  * Updated from global requirements
  * Move SessionClient from HTTPClient to adapter
  * resource-list --nested-depth stack_name column
  * Fix argument order for assertEqual
  * Updated from global requirements
  * Fixed VerifyAll() when test case does ReplayAll()
  * Updated from global requirements
  * Move test_event_utils.py module to unit directory
  * Add first pass at post_test_hook for functional
  * cleanup openstack-common.conf and sync updated files
  * Move usage methods *_request to get/post/etc
  * Updated from global requirements
  * Add functional tests from Tempest
  * Update hacking version to fix pep8 gate job
  * Adds --format=log option to event-list
  * Add --tags option to stack-create and stack-update
  * Add stack tag filtering options to stack-list
  * Add OS_TEST_PATH to testr
  * Move unittests to subdir unit
  * Updated from global requirements
  * Make hook type optional for hook-clear
  * Refactor common event code into event_utils module
  * Add hook-poll function to check if a stack has pending hooks
  * Work around pypy testing issue
  * Implement --limit option for event-list with --nested-depth
  * event-list marker, only slice when needed
  * Add option to show hidden stacks in stack-list
  * Add an option to generate template based on resource type
  * Updated from global requirements
  * Implement --marker for event-list --nested-depth
  * Fix sort column for event-list with nested-depth
  * Unit tests for stack actions
  * correction in function names under test_resource
  * Uncap library requirements for liberty
  * Add --nested-depth option to event-list
  * Make README.rst comply with expected format
  * Remove the deprecated shell commands
- Adjust Requires according to requirements.txt
- Add python_requires to _service file
* Wed Aug  5 2015 dmueller@suse.com
- add %%name-rpmlintrc
* Fri Apr 24 2015 tbechtold@suse.com
- Use %%{version} in source
* Thu Apr 23 2015 tbechtold@suse.com
- Switch to version 0.4.0
* Tue Apr 21 2015 cloud-devel@suse.de
- Update to version python-heatclient-0.4.0.post5:
  * correction in function names under test_resource
* Sat Apr 18 2015 cloud-devel@suse.de
- Update to version python-heatclient-0.4.0.post4:
  * Uncap library requirements for liberty
* Fri Apr 10 2015 cloud-devel@suse.de
- Update to version python-heatclient-0.4.0.post3:
  * Make README.rst comply with expected format
* Wed Apr  8 2015 cloud-devel@suse.de
- Update to version python-heatclient-0.4.0.post1:
  * Remove the deprecated shell commands
  0.4.0
* Thu Apr  2 2015 cloud-devel@suse.de
- Update to version python-heatclient-0.3.0.post23:
  * Parse nested files if they are template
  * Fix test class names
* Wed Apr  1 2015 cloud-devel@suse.de
- Update to version python-heatclient-0.3.0.post19:
  * Add wildcard support to hook-clear
  * Add options for setting and clearing of hooks
  * Add option for heatclient to accept parameter value from file
* Sat Mar 28 2015 cloud-devel@suse.de
- Update to version python-heatclient-0.3.0.post16:
  * Sync with oslo_incubator
* Wed Mar 25 2015 cloud-devel@suse.de
- Update to version python-heatclient-0.3.0.post14:
  * Migrate to new oslo_xxx namespace
* Mon Mar 23 2015 cloud-devel@suse.de
- Update to version python-heatclient-0.3.0.post13:
  * Updated from global requirements
* Wed Mar 18 2015 cloud-devel@suse.de
- Update to version python-heatclient-0.3.0.post12:
  * Implement deployment-create
* Wed Mar 11 2015 cloud-devel@suse.de
- Update to version python-heatclient-0.3.0.post11:
  * Implement deployment-output-show
* Thu Mar  5 2015 cloud-devel@suse.de
- Update to version python-heatclient-0.3.0.post10:
  * Make ; parsing optional in format_parameters
  * Updated from global requirements
* Wed Mar  4 2015 cloud-devel@suse.de
- Update to version python-heatclient-0.3.0.post7:
  * Fix SessionClient error when endpoint=None
* Sat Feb 21 2015 cloud-devel@suse.de
- Update to version python-heatclient-0.3.0.post6:
  * Sort event-list by oldest first
* Thu Feb 19 2015 cloud-devel@suse.de
- Update to version python-heatclient-0.3.0.post4:
  * Fix non-working endpoint type argument
* Sat Feb 14 2015 cloud-devel@suse.de
- Update to version python-heatclient-0.3.0.post3:
  * Updated from global requirements
  * Updates heat.rst with 'service-list
  0.3.0
* Tue Feb 10 2015 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.post70:
  * Adds CLI heat service-list
* Sat Feb  7 2015 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.post68:
  * Format attributes as JSON in resource-show output
* Thu Feb  5 2015 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.post66:
  * Add adopt/abandon description to heat manual
* Wed Feb  4 2015 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.post65:
  * Fix different behavior in python3.4 json module
* Thu Jan 29 2015 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.post64:
  * Updated from global requirements
  * Add CLI commands to interact with software-config
  * output-show format by json or raw
* Thu Jan 15 2015 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.post59:
  * CLI: Add --all option to output-show command
  * Removed http proxy environment variable so that httpretty can work
  * Updated from global requirements
* Fri Jan  9 2015 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.post55:
  * Replace httpretty with requests-mock
* Thu Jan  8 2015 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.post54:
  * Fix passing an object url to the heat CLI
  * Cleanup shell tests
* Fri Dec 26 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.post51:
  * Add transtlation markers for log messages
* Mon Dec 15 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.49.gd6d5197:
  * Add transtlation markers for error messages
  * Add transtlation markers for help messages
* Sat Dec 13 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.45.g892d423:
  * Updated from global requirements
* Fri Dec 12 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.44.g49d1448:
  * Curl statements to include globoff for IPv6 URLs
* Thu Dec 11 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.42.gad63852:
  * Initial setup for i18n support
  * Show the creation_time for stack snapshot list
  * Workflow documentation is now in infra-manual
  * Add support for parameter_defaults in environment
* Sat Dec  6 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.34.g9fffbd8:
  * Remove remaining deprecated oslo-incubator modules
* Fri Dec  5 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.33.g0e93da5:
  * Convert importutils to oslo.utils
* Wed Dec  3 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.32.g5e9e651:
  * Updated from global requirements
  * Convert strutils to oslo.utils.encodeutils
* Fri Nov 28 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.28.gd0b0270:
  * Fix H302 errors
* Tue Nov 25 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.27.g78af7de:
  * Implement restore operation
  * Implement snapshot operations
* Thu Nov 20 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.23.ge6949d0:
  * Updated from global requirements
* Sat Nov 15 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.22.g59a2e3d:
  * Move to oslo.serialization
* Wed Nov 12 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.20.gca403cc:
  * Tests work fine with random PYTHONHASHSEED
  * Updated from global requirements
  * Remove _ from builtins
  * Fix template_utils tests for Python 3.4
* Thu Oct 30 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.14.g73692bb:
  * Fix event tests for Python 3.4
  * Fix shell tests for Python 3.4
  * Allow mock-based patching in shell tests
* Mon Oct 27 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.11.g49d000c:
  * Make sure the --heat-url option is respected
  * Put a cap on our cyclomatic complexity
  * Pass auth_url if os_no_client_auth specified
* Mon Oct 13 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.6.g3d402d4:
  * Updated from global requirements
* Sat Oct 11 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.5.g0d5ad3f:
  * Updated from global requirements
  * Fixed null str returned for incorrect parameter
* Fri Oct 10 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.12.1.g21bee9e:
  * Remove extraneous vim editor configuration comments
  0.2.12
* Fri Sep 26 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.11.6.g6089d31:
  * Add a required 'args' to do_list()
  * Client supports check action
* Thu Sep 25 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.11.4.g346e163:
  * Add a required 'args' to do_list(
* Tue Sep 23 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.11.3.g21b81cc:
  * Fix stack update for Python API
* Mon Sep 22 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.11.1.g5b98523:
  * Updated from global requirements
* Sat Sep 20 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.11:
  0.2.11
  * Add 'cancel_update' action and command
  * Updated from global requirements
* Fri Sep 19 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.10.51.gd79f5b8:
  * Add stack-update argument for reset parameters
  * Add stack-update argument for patching parameters
  * Add support for OSprofiler
  * Stop using intersphinx
* Thu Sep 18 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.10.43.gc29f12a:
  * Display stack owner info on stack-list
* Wed Sep 17 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.10.42.g3a05689:
  * Reuse existing disable_rollback in stack-update
  * warn against sorting requirements
* Tue Sep 16 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.10.38.gf27a357:
  * Add --show-nested option to stack-list
* Sun Sep 14 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.10.36.g95841b5:
  * handles keyboard interrupt
* Fri Sep 12 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.10.34.g407a699:
  * Re-add keystone v3 auth with fixes
  * Template is not required on stack-adopt
* Wed Sep 10 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.10.31.gf826bd6:
  * output-file option in stack-abandon
* Thu Aug 28 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.10.30.g4bc53ac:
  * Handle upper cased endpoints (bnc#899545)
  * Remove unused/mutable default args
  * Don't expose X-Auth-Token in heat CLI
* Wed Aug 27 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.10.24.g8fe0c09:
  * Update stack-preview usage text
* Tue Aug 26 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.10.22.g949d7d8:
  * Updated from global requirements
* Sun Aug 24 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.10.21.g8435e19:
  * Removed undefined method in install_env.py file
  * Add support for multiple environment files
* Sat Aug 23 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.10.17.g7bbd75f:
  * Added timeout and rollback params in stack-preview
* Thu Aug 21 2014 tbechtold@suse.com
- Update to version python-heatclient-0.2.10.15.gb787a3b:
  * Add nested-depth option to resource-list
  * Update theme for docs
  * Add a tox job for generating docs
- Add python-oslosphinx as BuildRequires according to test-requirements.txt
* Wed Jul 30 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.10.9.g3985302:
  * Add rel field to links display
* Tue Jul 29 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.10.7.g42c5096:
  * Revert "Add keystone v3 auth support"
* Fri Jul 25 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.10.6.g6eb4562:
  * Implement events pagination, sorting and filtering
* Tue Jul 22 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.10.5.ga98c1f3:
  * Add keystone v3 auth support
* Thu Jul 17 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.10.4.g47232fa:
  * Deprecate misleading cli command 'resource-template'
* Mon Jul  7 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.10.3.g520a824:
  * Show physical_resource_id in resource-list
  * Fix the section name in CONTRIBUTING.rst
* Fri Jun 27 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.10:
  0.2.10
  * Improve --debug logging output
  * Fix unicode display in parameters
* Wed Jun 25 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.9.37.ga116890:
  * Do not set up logging handler in http
  * Updated from global requirements
* Fri Jun 13 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.9.35.g93dcf95:
  * Append extra space after command in bash_completion
  * Removed now unnecesary workaround for PyPy
  * Don't allow "propagate" of heatclient logger
  * Add option to show soft-deleted stacks in stack-list
  * Remove no use option parameters for template-validate
  * Let server order event-list
* Wed Jun 11 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.9.23.g422554b:
  * Add shell arguments for stack update
* Wed May 28 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.9.21.gc29e863:
  * Client should support stack-list for global scope
  * Mark heatclient as being a universal wheel
* Wed May 21 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.9.17.g94d10f9:
  * Fix empty resource list index out of range error
  * Add code coverage in resource list test
* Sat May 10 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.9.13.g5a78fdf:
  * fixed typos found by RETF rules
* Wed Apr 30 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.9.12.gaa36040:
  * Heat client does not support OS_CACERT option
* Fri Apr 18 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.9.10.g27b1ab9:
  * Add a description of how stack-abandon works
* Tue Apr 15 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.9.8.gf0fdb3e:
  * Remove unused arguments for stack-preview command
  * Use correct order of arguments to assertEqual
* Mon Apr 14 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.9.4.gde2df06:
  0.2.9
  * Deprecate preview --create-timeout in favor of --timeout
  * Sync oslo incubator
* Sun Apr 13 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.8.49.g2efd2e5:
  * Updated from global requirements
* Sat Apr 12 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.8.48.g4ea6a6d:
  * Process provider templates for included files
* Fri Apr  4 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.8.47.g2f07742:
  * Support Python 3
  * Python 3: fix test_template_utils.py
  * Python3: fix a bytes/str issue
* Wed Apr  2 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.8.42.gf42c1c9:
  * Python 3: decode bytes before feeding them to jsonutils.loads()
* Tue Apr  1 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.8.40.gdd10b2b:
  * Skip timeout_mins when not specify
* Mon Mar 31 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.8.38.g13b4f82:
  * Resolve files in resource types
* Wed Mar 26 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.8.36.g53b581f:
  * get_file: encode non utf-8 encoding files via base64
  * get_file: do not read same url once again
  * Do not use the '+' operation with dict_items()
  * Updated from global requirements
* Tue Mar 25 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.8.29.g508b6bb:
  * Using common methods from oslo cliutils
  * Output warnings for deprecated commands
  * Python 3: Fix YamlEnvironmentTest tests
  * Sort requirement files in alphabetical order
* Sat Mar 22 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.8.21.g644d148:
  * Add new tests to cover most of the requests port
  * Pass bytes to NamedTemporaryFile.write()
* Fri Mar 21 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.8.17.g8a51be6:
  * Add stack-preview support
  * Workaround failing pypy gate job
  * Remove dependent module py3kcompat
  * Oslo: sync strutils
  * Modify stack ID lookup to only use stacks:lookup
* Wed Mar 19 2014 dmueller@suse.com
- install bash_completion for heat
* Sat Mar 15 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.8.8.g7e265ec:
  * Add timeout option to stack-update
  * Deprecate create/adopt --create-timeout in favor of --timeout
  * Remove unused versions define in template_format.py
  * Python3: fix test_stack_list_with_args()
* Thu Mar 13 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.8.2.g3809893:
  * Rename --timeout global option and make it work
* Thu Mar  6 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.8.1.gaa30e46:
  * Enable --help for each command
  0.2.8
* Sun Mar  2 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.7.34.gb048b1a:
  * Do not use the '+' operation dict_items()
  * Remove None for dict.get()
  * Update apiclient.base and reuse new functional
* Sat Mar  1 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.7.28.ga9f321e:
  * Expand get_file using to template scope
  * "version" section should be required in template
  * Replace try...except with assertRaises
* Wed Feb 26 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.7.22.g7083897:
  * Updated from global requirements
  * Improve help strings
  * Fixed incorrect indentation in the tests
  * Don't use request builtin redirect for any methods
* Tue Feb 25 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.7.15.g55ad4b7:
  * Support the native signal API
  * Python3: fix bytes/str issues
* Fri Feb 21 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.7.11.g60f3de4:
  * add output-list and output-show
  * Adding stack-adopt support to python-heatclient
  0.2.7
  * Only call decode() on bytes
  * Do not use the '+' operation dict_items()
  * get_file_contents: use six.itervalues() instead of dict.itervalues()
  * Improve help strings
* Wed Feb 19 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.6.117.g1dabd8c:
  * REST method to fetch deployments metadata for a server
  * Make POST/PUT redirects use original methods
  * Decode all headers before logging curl commands
  * Python3: use six.iteritems() rather than dict.iteritems()
* Tue Feb 18 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.6.109.gaa1f09e:
  * Add support for software config resources
  * Fixes environment file using correct YAML format
  * Add optional args arg back to do_list
* Fri Feb 14 2014 cloud-devel@suse.de
- Update to version python-heatclient-0.2.6.104.g42099da:
  * normalise_file_path_to_url: use urlutils.pathname2url
* Thu Feb 13 2014 dmueller@suse.com
- fix requires
* Tue Feb 11 2014 speilicke@suse.com
- Update to version python-heatclient-0.2.6.103.g448d303:
  + python-heatclient stack-abandon support
  + Add more default CA paths
  + Port to python requests
  + Enable default in bash completion
  + Allow environment to not have resource_registry
  + Add filter option to stack-list
  + Add pagination (limit and marker) to stack-list
  + Populate files with content from get_file function calls
  + Enable hacking H233 rule
  + Configure logging regardless of debug flag
- Replace git_tarballs source service with download_files and set_version
  + Use upstream URL as source (enables verification)
* Tue Feb  4 2014 opensuse-cloud@opensuse.org
- Update to version 0.2.6.84:
  + Fix order of arguments in assertEqual
* Fri Jan 31 2014 opensuse-cloud@opensuse.org
- Update to version 0.2.6.83:
  + Pass empty dict not None for empty environment
* Wed Jan 29 2014 opensuse-cloud@opensuse.org
- Update to version 0.2.6.82:
  + Remove unused method 'string_to_bool' from utils
  + Updated from global requirements
  + Add support for build info API
* Mon Jan 27 2014 opensuse-cloud@opensuse.org
- Update to version 0.2.6.76:
  + Remove dependencies on pep8, pyflakes and flake8
  + Refactor environment functions in preparation for get_file
* Fri Jan 24 2014 opensuse-cloud@opensuse.org
- Update to version 0.2.6.72:
  + Use template_format.parse for local stack parsing
  + reconcile prepare_environment_file/url into one funtion
  + Raise traceback on error when using CLI and -debug
  + Copy run_test.sh from heat repo
  + Move environment and template file functions to own module
  + Test coverage of empty environment
  + Improve and unit-test template contents fetching
* Mon Jan 20 2014 opensuse-cloud@opensuse.org
- Update to version 0.2.6.58:
  + Move template_format from heat to heatclient
  + Fetch environment from fields rather than function arg
* Sat Jan 18 2014 opensuse-cloud@opensuse.org
- Update to version 0.2.6.54:
  + Fix comparison with singletons
  + Use assertRaises instead of try/except/else
* Fri Jan 17 2014 opensuse-cloud@opensuse.org
- Update to version 0.2.6.50:
  + Remove unused common.base module
* Thu Jan 16 2014 dmueller@suse.com
- fix requires
* Thu Jan 16 2014 opensuse-cloud@opensuse.org
- Update to version 0.2.6.48:
  + Add to_dict() method to Resource class
  + Update variable name in test_shell.py
  + Fix some trivial py3 errors
  + Sync strutils from oslo
* Fri Jan 10 2014 opensuse-cloud@opensuse.org
- Update to version 0.2.6.40:
  + Added API reference document
  + Remove vim header
  + Enable deleting multiple stacks with single call
  + Remove ununsed httplib2 requirement
* Thu Jan  9 2014 opensuse-cloud@opensuse.org
- Update to version 0.2.6.32:
  + Updates .gitignore
* Wed Jan  8 2014 opensuse-cloud@opensuse.org
- Update to version 0.2.6.30:
  + Increase test_resources coverage
* Tue Jan  7 2014 opensuse-cloud@opensuse.org
- Update to version 0.2.6.28:
  + Fix help formatting for resource-template
* Mon Jan  6 2014 opensuse-cloud@opensuse.org
- Update to version 0.2.6.26:
  + Sort resource-type-list output
* Sat Jan  4 2014 opensuse-cloud@opensuse.org
- Update to version 0.2.6.24:
  + Fixed typo error OS_IMAGE_URL
  + Wrapped some long lines
* Thu Jan  2 2014 opensuse-cloud@opensuse.org
- Update to version 0.2.6.22:
  + Fix inappropriate error message on event-list
* Sat Dec 21 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.6.21:
  + Allow the environment file to be specified via URL
  + Show better error when json fail to parse template
* Fri Dec 20 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.6.17:
  + Sync base and exceptions from oslo
  + Reuse BaseManager and Resource from oslo
* Wed Dec 18 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.6.13:
  + Supports bash_completion for heatclient
  + Misc typos in Heat client
* Tue Dec 17 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.6.11:
  + Deprecate mox in favor of mox3
  + Use jsonutils from oslo incubator
* Mon Dec 16 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.6.7:
  + Updated from global requirements
  + Updates tox.ini to use new features
* Sat Dec 14 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.6.3:
  + Add support for resource_types
* Wed Dec 11 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.6.2:
  + Replace inheritance hierarchy with composition
* Sat Dec  7 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.6.1:
  + Change ID column of Event table to UUID
* Fri Dec  6 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.5.54:
  + Fix i18n error when resource-name is non-english
  + Add --include-pass option for grizzly backwards compat
  + Add back --token-only for invocation compatibility
* Wed Dec  4 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.5.50:
  + Revert "Don't call credentials_headers() twice"
* Fri Nov 29 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.5.49:
  + use correct url on Windows platform
  + Fix shell operation with --os-auth-token
  + test_shell test current not deprecated options
  + Make tokens work with --os-no-client-auth
  + Honor endpoint_type when requesting keystone for a token
* Thu Nov 28 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.5.39:
  + Pass only tenant name or ID to keystoneclient
  + Cleanup exc.verbose after tests
  + Use fixtures for all shell environment variables
  + Don't call credentials_headers() twice
* Wed Nov 27 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.5.35:
  + Remove --token-only option, it does nothing
* Tue Nov 26 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.5.34:
  + Revert "heatclient is not working with os-auth-token"
* Mon Nov 25 2013 dmueller@suse.com
- switch to python-setuptools
* Sun Nov 24 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.5.32:
  + Updated from global requirements
* Thu Nov 21 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.5.30:
  + Encode output for fixing UnicodeDecodeError
* Wed Nov 13 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.5.29:
  + Add a basic man page for heat
* Tue Nov 12 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.5.28:
  + heatclient is not working with os-auth-token
* Sat Nov  9 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.5.26:
  + Returning the json body after a stack-create or stack-update
* Sat Nov  2 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.5.25:
  + Add a contibuting section to index.rst
  + Add a top level introduction to the index
* Fri Nov  1 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.5.21:
  + Add doc/Makefile to help with building docs
  + Resync doc/source/conf.py from heat for consistency
  + Remove the release notes as it is not maintained here
* Thu Oct 31 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.5.15:
  + Print a more correct error with event-show
* Sat Oct 26 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.5.14:
  + Fix the testname of scenario
* Wed Oct 23 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.5.13:
  + Import urlutils from openstack common
  + Use the six library for compatability
  + Transform print statement to print function
  + Replace urllib/urllib2 with urlutils
  + remove python 2.5 support for parse_sql
  + align the order of parameters for urlencode()
* Fri Oct 18 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.5.6:
  + Replace mox with mox3
  + Import httplib from six.moves
  + Updated from global requirements
* Mon Oct 14 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.5.3:
  + Allow env registry paths to be relative to env file
* Tue Oct  8 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.5.1:
  + Updated from global requirements
* Fri Sep 27 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.4.23:
  + Allow -P to be invoked multiple times
* Thu Sep 26 2013 dmueller@suse.com
- fix requires
* Thu Sep 19 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.4.21:
  + Replace OpenStack LLC with OpenStack Foundation
* Thu Sep 19 2013 dmueller@suse.com
- fix requires
* Thu Sep 12 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.4.20:
  + Support --version for heatclient
  + Stack instance identifier property
  + Add handler for heatclient.common.http
* Thu Sep  5 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.4.15:
  + Added support for running the tests under PyPy with tox
  + Fix and enable Hacking H501 warning
  + Be backward compatible after a renaming in API
* Wed Aug 28 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.4.10:
  + Add X-Region-Name parameter in HTTP request
* Tue Aug 27 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.4.8:
  + Rename event logical_resource_id to resource_name
* Mon Aug 26 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.4.7:
  + Do not obscure Unauthorized error messages
* Sat Aug 24 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.4.5:
  + Apply OS_REGION_NAME for endpoint selection
* Wed Aug 14 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.4.4:
  + Generate a template from a resource
* Sat Aug 10 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.4.2:
  + Fix heat event list sorted order incorrect
* Thu Aug  8 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.4.1:
  + Updated from global requirements
* Wed Aug  7 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.3.15.g2c05c73:
  + Add mock as a test requirement
  + Fix Stack instance delete method
  + Custom Stack get method to avoid lookup redirects
  + Do not paginate stack list unless page_size is set
  + Remove unused Stack data method
* Tue Aug  6 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.3.10.g9104cb0:
  + Sync with global requirements
* Mon Aug  5 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.3.9.g529d429:
  + Implement Stack status and action properties
* Tue Jul 30 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.3.8.gcae2c0f:
  + Parse error object (in json format) returned by heat-api
* Mon Jul 22 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.3.6.ge5d68a4:
  + Validate heat url is supplied for --os-no-client-auth.
  + Set credentials headers if there is no auth token.
* Wed Jul 17 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.3.2.ga49cf4c:
  + Make the parameter checking consistent.
  + Only set X-Auth-User, X-Auth-Key on stack create/update.
  + Display yaml format for stack deployed via hot template
  + Cleanup in preperation for release.
* Mon Jul 15 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.37.gff2033a:
  + Raise requirements to be in sync with OpenStack/Requirements
  + Rename README.md to README.rst
* Sun Jul 14 2013 dmueller@suse.com
- move heat client to main package
* Thu Jul 11 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.34.ga4208dc:
  + Fix "heat validate" (add needed environment option)
* Thu Jul 11 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.32.gcb5b027:
  + Update upper bound of keystoneclient version.
* Fri Jul  5 2013 dmueller@suse.com
- update requires
* Wed Jul  3 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.31.g9cba3da:
  + Add support for suspend/resume actions
  + Unit tests for pretty table special formatters.
  + Format resource required_by in resource-show.
* Sun Jun 30 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.26.g7774ac3:
  + Upload provider templates referenced in the environment.
* Thu Jun 27 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.25.ga77fd13:
  + Fix all the pep8  E* and F* errors.
  + Fix all but H302 hacking rules.
* Thu Jun 27 2013 speilicke@suse.com
- Only depend on python-discover on SLE, it's a Python-2.6 feature
  backport
* Wed Jun 26 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.23.g61ce603:
  + Fix various smaller pep8 issues
* Mon Jun 17 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.22.gf524528:
  + flake8 ignore build directory.
  + Stop passing path to VerifiedHTTPSConnection
* Wed Jun 12 2013 dmueller@suse.com
- fix test requires
* Wed Jun 12 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.19.g0e559f5:
  + Remove explicit distribute depend.
  + Include .testr.conf in source tarball
* Tue Jun 11 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.16.g5f3e7ef:
  + Use Python 3.x compatible except: construct
* Fri Jun  7 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.14.gb1eab17:
  + Add support for environment files
* Mon Jun  3 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.12.g6aeb099:
  + Migrate to testr from nose.
* Sun Jun  2 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.10.g9b1ce21:
  + Fixes text split for parameters
* Wed May 29 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.9.g2e6e49f:
  + Move requirements files to standard names.
  + Move tests into package dir.
  + Migrate test base classes to testtools.
* Mon Mar 18 2013 speilicke@suse.com
- Drop +git.$TIMESTAMP.$COMMITHASH version suffix
* Mon Mar 11 2013 cloud-devel@suse.de
- Update to version 0.2.0+git.1362996290.841ded0:
  + Remove warlock from pip-requires as it is not used
* Tue Mar  5 2013 cloud-devel@suse.de
- Update to version 0.2.0+git.1362502337.b6ff6d2:
  + Change --disable-rollback option to --enable-rollback
* Thu Feb 28 2013 saschpe@suse.de
- Update to version 0.2.0+git.1362055982.ec0a708:
  + Don't add 'dev' to tag_build
* Sun Feb 24 2013 cloud-devel@suse.de
- Update to version 0.2.0dev+git.1361729954.f1baa75:
  + heatclient : correct timeout parameter name
  + heatclient : Add --disable-rollback option
* Fri Feb 22 2013 saschpe@suse.de
- BuildRequire openstack-suse-macros instead of openstack-macros
* Mon Feb 18 2013 cloud-devel@suse.de
- Update to version 0.2.0dev+git.1361180419.84b7969:
  + Return the exit code from tox to callers of run_tests.sh
* Mon Feb  4 2013 dmueller@suse.com
- Update to version 0.2.0dev+git.1359979473.bcaf6c4:
  + Add switch to disable token authentication.
  + Don't log at all if debugging is not turned on
* Mon Jan 14 2013 saschpe@suse.de
- Update to version 0.2.0dev+git.1358164800.7f50a72:
  + Fixes required for packaging
- Updated requirements
* Wed Jan  9 2013 saschpe@suse.de
- Move service to tarballs.opensuse.org, upstream now provides tarballs
  for python-heatclient
- Update to version 0.1.0.2.gb1b5455+git.1357718136.b1b5455:
  + Relax the required version of prettytable.
* Wed Dec 19 2012 saschpe@suse.de
- Move to obs-service-git_tarballs
  + Drop BuildRequires: python-setuptools-git
- Update to version 0.1.0.1.gc7130de+git.1355925790.c7130de:
  + Display a better error message on HTTP exception
  + Fix git repo url
  + Deprecate commands and add unified cli replacements.
  + remove some glanceisms from the docs
  + add some pypi meta info
  + Update .gitreview for org move.
  + Support for events list and details
  + Use python-keystoneclient 0.2 series
  + Pass template as a string if it is not JSON.
* Wed Dec  5 2012 saschpe@suse.de
- Use @PARENT_TAG@ in _service file to automate versioning
* Mon Nov 26 2012 saschpe@suse.de
- Cleanup (build) dependencies
* Mon Nov 26 2012 saschpe@suse.de
- Initial version
